@@ -1,40 +1,52 @@
-#' @title Leaflet plugin - Spanish providers
-#' @name addProviderEspTiles
-#' @description Add tiles of
-#' \href{https://dieghernan.github.io/leaflet-providersESP/}{leaflet-providersESP}
-#' to a \strong{R} \link[leaflet]{leaflet} map.
-#' @source \href{https://dieghernan.github.io/leaflet-providersESP/}{leaflet-providersESP}
-#' leaflet plugin, \strong{v1.2.0}.
-#' @return Modified \code{map} object.
-#' @author dieghernan, \url{https://github.com/dieghernan/}
-#' @seealso \link{leaflet.providersESP.df}, \link{esp_getTiles}
+#' Leaflet plugin - Spanish providers
+#'
+#' @concept imagery
+#'
+#' @rdname addProviderEspTiles
+#'
+#' @description
+#' Add tiles of <https://dieghernan.github.io/leaflet-providersESP/> to a
+#' **R** [leaflet::leaflet()] map.
+#'
+#' @source
+#' <https://dieghernan.github.io/leaflet-providersESP/> leaflet plugin,
+#'  **v1.2.0**.
+#'
+#' @return Modified `map` object.
+#'
+#' @author dieghernan, <https://github.com/dieghernan/>
+#'
+#' @seealso [leaflet.providersESP.df], [esp_getTiles()]
+#'
 #' @export
 #'
-#' @param provider Name of the provider, see \link{leaflet.providersESP.df}.
-#' @param map,layerId,group,options See \link[leaflet]{addTiles}
+#' @param provider Name of the provider, see [leaflet.providersESP.df].
+#'
+#' @inheritParams leaflet::addTiles
+#'
 #' @examples
 #' library(leaflet)
-#'   PuertadelSol <-
-#'     leaflet() %>% setView(lat = 40.4166,
-#'                           lng = -3.7038400,
-#'                           zoom = 18) %>%
-#'     addProviderEspTiles(provider = "IGNBase.Gris") %>%
-#'     addProviderEspTiles(provider = "RedTransporte.Carreteras")
-#'
-#'     PuertadelSol
-#'
-#'
+#' PuertadelSol <-
+#'   leaflet() %>%
+#'   setView(
+#'     lat = 40.4166,
+#'     lng = -3.7038400,
+#'     zoom = 18
+#'   ) %>%
+#'   addProviderEspTiles(provider = "IGNBase.Gris") %>%
+#'   addProviderEspTiles(provider = "RedTransporte.Carreteras")
 #'
+#' PuertadelSol
 addProviderEspTiles <- function(map,
                                 provider,
                                 layerId = NULL,
                                 group = NULL,
                                 options = providerEspTileOptions()) {
   # A. Check providers
-  leafletProvidersESP <-
+  providers_df <-
     as.data.frame(mapSpain::leaflet.providersESP.df)
   provs <-
-    leafletProvidersESP[leafletProvidersESP$provider == provider, ]
+    providers_df[providers_df$provider == provider, ]
 
   if (nrow(provs) == 0) {
     stop(
@@ -42,8 +54,9 @@ addProviderEspTiles <- function(map,
       provider,
       "' found. Available providers are:\n\n",
       paste0("'",
-             unique(leafletProvidersESP$provider), "'",
-             collapse = ", ")
+        unique(providers_df$provider), "'",
+        collapse = ", "
+      )
     )
   }
 
@@ -75,7 +88,7 @@ addProviderEspTiles <- function(map,
 
 
   # Clean if the option was already set
-  opts <- opts[!(opts$field %in% names(options)),]
+  opts <- opts[!(opts$field %in% names(options)), ]
 
   # Pass to list
 
@@ -86,11 +99,10 @@ addProviderEspTiles <- function(map,
     value <- paste(opts[j, 2])
 
     opinit[[name]] <- value
-
   }
 
   options <- c(options, opinit)
-  rm(opts, provs, leafletProvidersESP, opinit)
+  rm(opts, provs, providers_df, opinit)
 
   # Replace on template
 
@@ -139,10 +151,15 @@ addProviderEspTiles <- function(map,
 }
 
 #' @rdname addProviderEspTiles
-#' @details \code{providerEspTileOptions} is a wrapper of
-#' \code{leaflet::providerTileOptions}
-#' @param ...  Additional options. See \link[leaflet]{providerTileOptions}.
-#' @seealso \link[leaflet]{tileOptions}, \link[leaflet]{providerTileOptions}
+#'
+#' @concept imagery
+#'
+#' @details Wrapper of [leaflet::providerTileOptions()]
+#'
+#' @inheritDotParams leaflet::providerTileOptions
+#'
+#' @seealso [leaflet::providerTileOptions()], [leaflet::tileOptions()]
+#'
 #' @export
 providerEspTileOptions <- function(...) {
   ops <- leaflet::providerTileOptions(...)
